@@ -167,22 +167,22 @@ static const guint8 radio_on[] =
   "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
   "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
   "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
-  "\0\0\0\0\0l\0\0\0\310\0\0\0\332\0\0\0\310\0\0\0H\0\0\0\0\0\0\0\0\0\0"
-  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0l\0\0\0l\0\0\0U\0\0\0\310\0"
-  "\0\0\310\0\0\0\332\0\0\0H\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
-  "\0\0\0\0\0\310\0\0\0U\0\0\0\310\0\0\0\310\0\0\0\310\0\0\0\332\0\0\0\310"
-  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\332\0\0\0\310"
-  "\0\0\0\310\0\0\0\310\0\0\0\310\0\0\0\332\0\0\0\332\0\0\0\0\0\0\0\0\0"
-  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\310\0\0\0\332\0\0\0\310\0\0\0\310"
-  "\0\0\0\332\0\0\0\332\0\0\0\310\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
-  "\0\0\0\0\0\0\0\0H\0\0\0\332\0\0\0\332\0\0\0\332\0\0\0\332\0\0\0\332\0"
-  "\0\0H\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0H"
-  "\0\0\0\310\0\0\0\332\0\0\0\310\0\0\0H\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
+  "\0\0\0\0\0H\0\0\0\310\0\0\0\332\0\0\0\310\0\0\0H\0\0\0\0\0\0\0\0\0\0"
+  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0H\0\0\0\332\0\0\0\332\0\0\0"
+  "\332\0\0\0\332\0\0\0\332\0\0\0H\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
+  "\0\0\0\0\0\0\0\0\310\0\0\0\332\0\0\0\310\0\0\0\310\0\0\0\332\0\0\0\332"
+  "\0\0\0\310\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\332"
+  "\0\0\0\310\0\0\0\310\0\0\0\310\0\0\0\310\0\0\0\332\0\0\0\332\0\0\0\0"
+  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\310\0\0\0\332\0\0\0\310"
+  "\0\0\0\310\0\0\0\332\0\0\0\332\0\0\0\310\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
+  "\0\0\0\0\0\0\0\0\0\0\0\0\0H\0\0\0\332\0\0\0\332\0\0\0\332\0\0\0\332\0"
+  "\0\0\332\0\0\0H\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
+  "\0\0\0\0H\0\0\0\310\0\0\0\332\0\0\0\310\0\0\0H\0\0\0\0\0\0\0\0\0\0\0"
   "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
   "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
   "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
   "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
-  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"};
+  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"};
 
 
 /* GdkPixbuf RGBA C-Source image dump */
